@@ -28,11 +28,18 @@ class Anomaly(Enum):
     CONCEPT_DRIFT = "concept_drift"
     POPULARITY_BIAS = "popularity_bias"
     DATA_INTEGRITY = "data_integrity"
-    AGGREGATE = "aggregate"
+
+
+class Statistic(Enum):
+    DISTANCE = "distance"
     DISTRIBUTION_STATS = "distribution_stats"
     CONVERGENCE_STATS = "convergence_stats"
 
 
+class Visual(Enum):
+    UMAP = "umap"
+
+
 class DataDriftAlgo(Enum):
     DDM = "DDM"
 
@@ -50,3 +57,4 @@ class MeasurableType(Enum):
     CONDITION_ON_PREDICTION = "condition_on_prediction"
     SCALAR_FROM_EMBEDDING = "scalar_from_embedding"
     DISTANCE = "distance"
+    REC_HIT_RATE = "hit_rate"
